"use strict";
/**
 * @file amender.
 * @author tony7lee
 */
Object.defineProperty(exports, "__esModule", { value: true });
const path = require("path");
const utils_1 = require("../utils");
/**
 * loop amend
 *
 * @param {string} payload
 * @param {*} collect
 */
function loopAmend(payload, collect) {
    collect.forEach(item => {
        const { routePath, component, children } = item;
        // reduce routePath to the nested
        item.routePathAmend = routePath;
        if (payload && payload !== '/') {
            item.routePathAmend = routePath.replace(payload, '');
        }
        // tansform component name
        item.component = utils_1.transformComponentName(component);
        if (children) {
            loopAmend(routePath, children);
        }
    });
}
/**
 * add default layout
 * default layout: `src/layouts/index.[jsx|tsx]`
 */
function addDefaultLayout(rootDir, routersTempPath, collect) {
    const rootRoute = collect && collect[0];
    // get the js like file
    const layoutJSFilePaths = utils_1.getJsFilePathsIn(path.join(rootDir, 'src/layouts/index'));
    const defaultLayoutExists = Boolean(layoutJSFilePaths.length);
    const defaultLayoutPath = layoutJSFilePaths[0] || '';
    const defaultLayoutPathRelative = utils_1.formatPathForWin(path.relative(path.dirname(routersTempPath), defaultLayoutPath));
    if (defaultLayoutExists) {
        // has layout nested such as _layout
        if (rootRoute && rootRoute.routePath === '/') {
            rootRoute.filePath = defaultLayoutPathRelative;
        }
        else {
            const spliceRoutes = collect.splice(0, collect.length);
            collect.push({
                routePath: '/',
                component: 'Layout',
                filePath: defaultLayoutPathRelative,
                isLayoutLike: true,
                children: spliceRoutes
            });
        }
    }
}
/**
 * add default 404
 * default file: `src/pages/404/index.[jsx|tsx]`
 */
function addDefault404(rootDir, routersTempPath, collect) {
    const rootRoute = collect && collect[0];
    // get the js like file
    const page404JSFilePaths = utils_1.getJsFilePathsIn(path.join(rootDir, 'src/pages/404/index'));
    const default404Exists = Boolean(page404JSFilePaths.length);
    const default404Path = page404JSFilePaths[0] || '';
    const default404PathRelative = utils_1.formatPathForWin(path.relative(path.dirname(routersTempPath), default404Path));
    if (default404Exists) {
        const config404 = {
            routePath: '',
            exact: String(false),
            component: 'Page404',
            filePath: default404PathRelative,
            isLayoutLike: false
        };
        if (rootRoute && rootRoute.routePath === '/') {
            // has layout nested such as _layout
            if (!rootRoute.children)
                rootRoute.children = [];
            rootRoute.children.push(config404);
        }
        else {
            collect && collect.push(config404);
        }
    }
}
function amender(rootDir, routersTempPath, routesCollect) {
    addDefaultLayout(rootDir, routersTempPath, routesCollect);
    addDefault404(rootDir, routersTempPath, routesCollect);
    loopAmend('', routesCollect);
}
exports.default = amender;
