"use strict";
/**
 * @file splicer.
 * @author tony7lee
 */
Object.defineProperty(exports, "__esModule", { value: true });
const utils_1 = require("../utils");
/**
 * loop splice
 *
 * @param {*} payload
 * @param {*} collect
 */
function loopSplice(payload, collect) {
    const indent = payload.indent;
    const indentTabs = utils_1.fillTabWith(indent);
    const indentTabsSub1 = utils_1.fillTabWith(indent - 1);
    // add 2 space per loop
    payload.indent += 2;
    // nest the array stucture
    payload.nestSlice.push(`[`);
    // run loop
    collect.forEach(item => {
        const { routePathAmend, component, filePath, children, isLayoutLike, exact } = item;
        // collect imports
        if (!payload.nestImportsNames.includes(component)) {
            payload.nestImports.push(`import ${component} from '${filePath}';\n`);
            // record component exists
            payload.nestImportsNames.push(component);
        }
        // nest object structure
        const defaultExact = exact || 'true';
        payload.nestSlice.push(`
${indentTabs}{
  ${indentTabs}path: '${routePathAmend}',
  ${indentTabs}exact: ${isLayoutLike ? 'false' : defaultExact},
  ${indentTabs}component: ${component},
  ${indentTabs}RouteWrapper: createRouteWrapper(${component}.pageConfig)`);
        if (children && children.length) {
            payload.nestSlice.push(`,
  ${indentTabs}children: `);
            // loop children
            loopSplice(payload, children);
            // children field end
            payload.nestSlice.push(`,`);
        }
        // nest object end
        payload.nestSlice.push(`
${indentTabs}},`);
    });
    // nest the array end
    payload.nestSlice.push(`\n${indentTabsSub1}]`);
}
function splicer(routesCollect) {
    // loop data
    const payload = { nestImports: [], nestImportsNames: [], nestSlice: [], indent: 1 };
    // init loop
    loopSplice(payload, routesCollect);
    return `import createRouteWrapper from './createRouteWrapper';\n${payload.nestImports.join('')}\nexport default ${payload.nestSlice.join('')};`;
}
exports.default = splicer;
