"use strict";
/**
 * @file walker.
 * @author tony7lee
 */
Object.defineProperty(exports, "__esModule", { value: true });
const path = require("path");
const fse = require("fs-extra");
const utils_1 = require("../utils");
const nest_1 = require("./nest");
const splicer_1 = require("./splicer");
const amender_1 = require("./amender");
function walker(rootDir, userOptions, routersTempPath, pagesDir) {
    const { ignoreRoutes, ignorePaths = {
        'pattern': '(^|.*/)components/.*',
    }, sensitiveRoute = false } = userOptions;
    const pageFilePaths = utils_1.getPagePaths(pagesDir);
    let routesCollect = [];
    const routesMap = {};
    const layoutMap = {};
    pageFilePaths.forEach(pageFilePath => {
        // ignore files
        const hitIgnoreFilePath = (Array.isArray(ignorePaths) && ignorePaths.includes(pageFilePath))
            || (utils_1.isObject(ignorePaths)
                && ignorePaths.pattern
                && new RegExp(ignorePaths.pattern, ignorePaths.attributes || '').test(pageFilePath));
        if (hitIgnoreFilePath)
            return;
        const { dir, name } = path.parse(pageFilePath);
        const dirArr = dir.split('/');
        // estimate _ layout syntax
        const isLayoutLike = utils_1.isNestFileName(name);
        // omit path from index.jsx/tsx
        const useMainFile = name === 'index';
        if (!useMainFile && !isLayoutLike)
            dirArr.push(name);
        const dirArrFormatSensitive = dirArr.filter(s => s);
        const dirArrFormat = dirArrFormatSensitive.map(s => s.toLowerCase());
        const dirArrUpper = dirArrFormat.map(s => utils_1.upperCaseFirst(s)).join('');
        // handle $ syntax: dynamic path
        const dirArrDynamic = sensitiveRoute ? dirArrFormatSensitive : dirArrFormat;
        const dirArrDynamicHandled = dirArrDynamic.map(i => {
            let out = i;
            // handle dynamic path
            if (utils_1.isOptionalDynamicPath(i)) {
                out = utils_1.transformOptionalDynamicPath(i);
            }
            else if (utils_1.isDynamicPath(i)) {
                out = utils_1.transformDynamicPath(i);
            }
            return out;
        });
        // get router path
        const routePath = `/${dirArrDynamicHandled.join('/')}`;
        // get other names
        const compName = `Page${dirArrUpper}`;
        const layoutName = `Layout${dirArrUpper}`;
        const filePath = utils_1.formatPathForWin(path.relative(path.dirname(routersTempPath), path.join(pagesDir, pageFilePath)));
        // ignore by user options.
        const ignoreKey = (Array.isArray(ignoreRoutes) && ignoreRoutes.includes(routePath))
            || (utils_1.isObject(ignoreRoutes)
                && ignoreRoutes.pattern
                && new RegExp(ignoreRoutes.pattern, ignoreRoutes.attributes || '').test(routePath));
        // use shorter path one when same route occurred.
        const isLongerPath = routesMap[routePath] && useMainFile;
        // ignore and back to loop
        if (isLongerPath || ignoreKey)
            return;
        // collect pages and layout
        let pageConfig = {
            routePath,
            component: compName,
            filePath,
            isLayoutLike: false
        };
        if (isLayoutLike) {
            pageConfig = {
                ...pageConfig,
                component: layoutName,
                isLayoutLike
            };
            layoutMap[routePath] = pageConfig;
        }
        else {
            routesMap[routePath] = pageConfig;
        }
        routesCollect = nest_1.default(layoutMap, pageConfig, routesCollect);
    });
    // amend collects
    amender_1.default(rootDir, routersTempPath, routesCollect);
    // generate splices
    let routesSplices = splicer_1.default(routesCollect);
    // output into .tmp
    fse.outputFileSync(routersTempPath, routesSplices);
    routesSplices = null;
}
exports.default = walker;
