"use strict";
/**
 * @file inject.
 * @author tony7lee
 */
Object.defineProperty(exports, "__esModule", { value: true });
const path = require("path");
const utils_1 = require("../utils");
function inject(rootDir, routersTempPath, applyMethod, TEM_ROUTER, userOptions) {
    // get the js like file
    const appJSFilePaths = utils_1.getJsFilePathsIn(path.join(rootDir, `src/app`));
    const appPath = appJSFilePaths[0] || '';
    const appFileExist = Boolean(appJSFilePaths.length);
    const appPathRelative = utils_1.formatPathForWin(path.relative(path.dirname(routersTempPath), appPath));
    const { inject = true, type = 'browser', basename } = userOptions;
    if (inject) {
        // inject with app.[j|t]s
        if (appFileExist) {
            applyMethod('agreementAppend', ['pipeAppHeader', (text) => `${text}
      import { Router } from '@ice/router';
      import routes from '${TEM_ROUTER}';`]);
            applyMethod('agreementAppend', ['pipeAppComponent', (text) => `
      const renderRoutes = ${applyMethod('checkRuntimeKey', 'modifyRoutes') ? 'modifyRoutes(routes)' : 'routes'};
      const customProps = ${applyMethod('checkRuntimeKey', 'routerProps') ? 'routerProps || {}' : '{}'};${text}`]);
            applyMethod('agreementAppend', ['pipeRouter', (text) => `<Router routes={renderRoutes} type={'${type}'} ${basename ? `basename={'${basename}'}` : ''} {...customProps} />`]);
        }
        else {
            // inject routes directly
            applyMethod('agreementAppend', ['pipeAppHeader', (text) => `${text}
    import { Router } from '@ice/router';
    import routes from '${TEM_ROUTER}';`]);
            applyMethod('agreementAppend', ['pipeRouter', (text) => `<Router routes={routes} type={'${type}'} ${basename ? `basename={'${basename}'}` : ''}/>`]);
        }
    }
}
exports.default = inject;
