"use strict";
/**
 * @file build-plugin-router.
 * @author tony7lee
 */
Object.defineProperty(exports, "__esModule", { value: true });
const path = require("path");
const fse = require("fs-extra");
const chores_1 = require("./handler/chores");
const inject_1 = require("./handler/inject");
const watcher_1 = require("./collector/watcher");
const TEM_ROUTER = 'ice/routes';
// compatible with $ice/router
const TEM_ROUTER_COMPATIBLE = '$ice/router';
const TEM_ROUTER_SETS = [TEM_ROUTER, TEM_ROUTER_COMPATIBLE];
function default_1({ context, onGetWebpackConfig, onHook, log, getValue, applyMethod }, userOptions = {}) {
    const { rootDir } = context;
    const { type = 'browser' } = userOptions;
    // [enum] js or ts
    const projectType = getValue('PROJECT_TYPE');
    // .tmp path
    const iceTempPath = getValue('ICE_TEMP');
    const routersTempPath = path.join(iceTempPath, `routes.${projectType}`);
    // add chores: alias and etc...
    chores_1.default(projectType, rootDir, TEM_ROUTER_SETS, routersTempPath);
    // inject to agreement
    inject_1.default(rootDir, routersTempPath, applyMethod, TEM_ROUTER, userOptions);
    // modify webpack config
    onGetWebpackConfig((config) => {
        // add alias
        TEM_ROUTER_SETS.forEach(i => {
            config.resolve.alias.set(i, routersTempPath);
        });
        // add devserver config
        if (type === 'browser') {
            config.devServer.set('historyApiFallback', true);
        }
    });
    function renderTemplate(fileName) {
        fse.ensureDirSync(iceTempPath);
        fse.copyFileSync(path.join(__dirname, `./template/${fileName}.tpl`), path.join(iceTempPath, `${fileName}.${projectType}x`));
    }
    renderTemplate('createRouteWrapper');
    onHook('before.start.run', async () => {
        watcher_1.default(false, rootDir, routersTempPath, userOptions);
    });
    onHook('before.build.run', async () => {
        watcher_1.default(true, rootDir, routersTempPath, userOptions);
    });
}
exports.default = default_1;
