"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const path = require("path");
const fs = require("fs");
const fileReg = /^(.*)\.(ts|js|tsx|jsx)$/;
function getModels(rootDir, iceTemp) {
    const storesDir = path.join(rootDir, '/src/stores');
    if (fsExistsSync(storesDir)) {
        const files = fsReadDir(storesDir)
            .filter((f) => fileReg.test(f))
            .map((f) => {
            const matcheds = f.match(fileReg);
            const modelPath = path.join(storesDir, f);
            const relativePath = path.relative(iceTemp, `${storesDir}/${matcheds[1]}`);
            return {
                name: matcheds[1],
                type: matcheds[2],
                fileName: f,
                modelPath,
                relativePath,
            };
        });
        const indexFile = files.filter(({ name }) => name === 'index');
        if (indexFile.length > 0) {
            // have index file
            return { hasIndex: true, models: indexFile };
        }
        else {
            return { hasIndex: false, models: files };
        }
    }
    else {
        return { hasIndex: false, models: [] };
    }
}
exports.default = getModels;
function fsExistsSync(dir) {
    try {
        fs.accessSync(dir);
    }
    catch (e) {
        return false;
    }
    return true;
}
function fsReadDir(dir) {
    try {
        return fs.readdirSync(dir);
    }
    catch (e) {
        return [];
    }
}
